@@ -1,10 +1,13 @@
 package DateTimeX::Format::CustomPattern;
+use Moose::Role;
+
 use strict;
 use warnings;
 
-use Moose::Role;
 use Carp;
 
+use namespace::clean -except => 'meta';
+
 has 'pattern' => (
 	isa         => 'Maybe[Str]'
 	, is        => 'rw'
@@ -58,11 +61,11 @@ It adds an attribute "pattern", and behavies consistant with the call-overriding
 	package main;
 
 	my $dt = DateTimeX::Format::RequiresPattern->new({
-		locale     => $locale
-		, timezone => $timezone
-		, pattern  => '%H:%M:%S'
-		, debug    => 0|1
-		, defaults => 0|1
+		locale       => $locale
+		, time_zone  => $timezone
+		, pattern    => '%H:%M:%S'
+		, debug      => 0|1
+		, defaults   => 0|1
 	});
 
 	$dt->parse_datetime( $time, {pattern => '%H:%M'} );
